:orphan:

*************
Package Files
*************

Classification
==============

The files of package ``ut-arr`` are classified into the following file types
(c.f.: **Appendix**: `Python Glossary`_):

.. _Python Glossary: glossary.html

#. **Special files**

   a. *py.typed*

#. **Special modules**

   a. *__init__.py*
   #. *__version__.py*

#. **Modules**

   a. *arr.py* — Array utilities
   #. *ao2a.py* — Arrays of two arrays
   #. *aoa.py* — Array of arrays
   #. *aod.py* — Array of dictionaries
   #. *aoo.py* — Array of objects
   #. *aos.py* — Array of strings
